Beam attenuation coefficient from absorption and scattering.
Source:R/optical_properties.R
beam_attenuation.RdThe beam (total) attenuation coefficient is the sum of the absorption and scattering coefficients, \(c = a + b\) (Johnsen 2012, ch. 5). It governs how a collimated beam — and the contrast of a sighted object — fades with distance, and is always larger than the diffuse attenuation \(K_d\).