Fresnel reflectance at the air-water interface.
Source:R/optical_properties.R
fresnel_reflectance.RdUnpolarised Fresnel reflectance for light crossing a flat air-water boundary,
as a function of incidence angle (Johnsen 2012, ch. 5). At normal incidence
about 2% of downwelling light is reflected (\(R = ((n-1)/(n+1))^2\)).
Going from water to air, total internal reflection (\(R = 1\)) occurs beyond
the critical angle (the edge of snells_window).
Arguments
- angle
Angle of incidence from the surface normal, in degrees (0-90). Vectorised.
- n
Refractive index of water relative to air. Default 1.333.
- from
Incident medium:
"air"(default) or"water".- component
Which polarization component to return:
"unpolarized"(default; the mean of the two),"s"(perpendicular / TE), or"p"(parallel / TM). The difference between the s- and p-components is why reflection off water partially polarizes light (vanishing for the p-component at Brewster's angle).