Read a calibrated Ocean Optics spectrum as a lux_spectrum
Source:R/spectrum_readers.R
from_ocean_optics.RdOcean Optics text files do not contain a standardized machine-readable unit
or calibration state. All physical declarations are therefore required.
Use read_ocean_optics to inspect raw or relative values.