Refracted zenith angle of the sun beneath the surface
Source:R/polarization.R
refracted_solar_angle.RdSnell's-law refraction of the solar beam entering water:
\(\theta_w = \arcsin(\sin\theta_{air} / n)\). As the in-air zenith
approaches 90 degrees the refracted angle approaches the edge of Snell's
window (about 48.6 degrees for n = 1.333); see
snells_window.